/*
 
  copyright (c) 2004, Michal Salaban <emes@pld-linux.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2 as
  published by the Free Software Foundation (see file COPYING for details).

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
*/

/* $Id: mainloop.c,v 1.4 2004/02/17 23:21:15 emes Exp $ */

#include <stdio.h>
#include <pthread.h>
#include "parseopt/lex.h"
#include "conditions.h"
#include "getstats.h"
#include "log.h"

pthread_mutex_t     changing_data;
int                 step = 10;

void rule_watch_loop (ruleset *rule)
{
    while (1) {
        /* save result of this and previous hit */
        rule->prevhit = rule->hit;

        /* lock mutex while checking data */
        pthread_mutex_lock (&changing_data);
        rule->hit = check_expression (rule->expr);
        pthread_mutex_unlock (&changing_data);

        if (rule->hit) {
#ifdef DEBUG
            printf ("Rule @%x hit.\n", (int) rule);
#endif
            /* first - log if neccessary */
            if (rule->log != NULL) {
                if (! (rule->log->once && rule->prevhit)) {
                    log_rulehit (rule);
#ifdef DEBUG
                    printf ("rule logged\n");
#endif
                }
            }
            
            /* second - run command */
            if (rule->run != NULL) {
                if (! (rule->run->once && rule->prevhit)) {
                    system (rule->run->runcmd);
#ifdef DEBUG
                    printf ("executed '%s'\n", rule->run->runcmd);
#endif
                }
            }
        } else {
#ifdef DEBUG                
            printf ("Rule @%x NOT hit.\n", (int) rule);
#endif
        }

        sleep (step);
    }
}
        

void res_probe_loop ()
{
    while (1) {
        
        /* lock mutex while changing data */
        pthread_mutex_lock (&changing_data);
        fetch_la ();
        fetch_mem ();
        pthread_mutex_unlock (&changing_data);

        sleep (step);            
    }
}


/* $Id: mainloop.c,v 1.4 2004/02/17 23:21:15 emes Exp $ */
